{ config, lib, pkgs, ... }:

{
  # Display manager
  services.xserver.enable = true;
  services.xserver.displayManager = {
    defaultSession = "sway";
    sddm = {
      enable = true;
      autoLogin = {
        enable = true;
        user = "coolneng";
      };
    };
  };

  # Window manager
  programs.sway = {
    enable = true;
    extraPackages = with pkgs; [
      xwayland
      swaylock
      swaybg
      rofi
      waybar
      clipman
      grim
      slurp
      light
      imv
      kanshi
      redshift-wlr
      kitty
    ];
    extraSessionCommands = ''
      export MOZ_ENABLE_WAYLAND=1
      export MOZ_DBUS_REMOTE=1
      export GRIM_DEFAULT_DIR=/home/coolneng/Photos/Screenshots
      export _JAVA_AWT_WM_NONREPARENTING=1
      export QT_QPA_PLATFORM=wayland
      export QT_WAYLAND_DISABLE_WINDOWDECORATION="1"
      export SDL_VIDEODRIVER=wayland
    '';
  };
   
  # Backlight
  programs.light.enable = true;

  # Blue light filter
  services.redshift = {
    package = pkgs.redshift-wlr;
    enable = true;
    temperature = {
      day = 6500;
      night = 5000;
    };
    extraOptions = [ "-m wayland" "-l manual"];
  };

  location = {
    latitude = 35.89;
    longitude = -5.32;
  };

  # Bar
  programs.waybar.enable = true;
}
